Description Usage Arguments Details Value Author(s) See Also Examples
This function takes a data file, the user's choice of column to do the comparisons by, the user's choice of column for the numeric values, checkes that these columnds are in the correct class and then will output a list that has the numeric values separated by each level of the variable the user wants to compare and a dataframe of the values for easy graphing in another function. There must be column names for this function to work.
1 | DataCleaner(x, fact, respo, warn = TRUE)
|
x |
Is a dataframe or other csv file read into R. |
fact |
The name of a column in |
respo |
The name of a column in |
warn |
Either |
The output of this function should be assigned to an object and that object used in the other functions of this package. If you want to subset by another column use SubsetCleaner() and not DataCleaner().
compare_list |
a list containing the level of the |
data_frame |
a dataframe of the |
Selina A. Ruzi
1 2 3 4 5 6 7 8 9 10 11 | ## -- find path
mypath <- system.file("extdata", "Example_data.csv", package="multipleComparisons")
## -- read in data
Example_data <- read.csv(mypath, header=TRUE)
names(Example_data)
## -- If do not want to further subset the data, do the following
myCleanData <- DataCleaner(Example_data, fact="Plot",
respo="Seed_removal_percent",
warn=FALSE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.