Description Usage Arguments Value Author(s) See Also Examples
This function takes a list created by either SubsetCleaner or DataCleaner and graphs boxplots for each of the fact levels.
1 2 |
data |
Is a list output from either |
groups |
Either |
clean_bg |
Either |
x_label |
X axis label. |
y_label |
Y axis label. |
bold_labels |
Either |
vert_facet |
Either |
A graph is returned.
Selina A. Ruzi
SubsetCleaner
DataCleaner
ggplot
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 | ## -- find path
mypath <- system.file("extdata", "Example_data.csv", package="multipleComparisons")
## -- read in data
Example_data <- read.csv(mypath, header=TRUE)
names(Example_data)
## -- If do not want to further subset the data, do the following
myCleanData <- DataCleaner(Example_data, fact="Plot",
respo="Seed_removal_percent",
warn=FALSE)
MyDataGraph <- GraphCompare(myCleanData, groups=FALSE, clean_bg=TRUE, x_label="Plot",
y_label ="Seed Removal Percent", bold_labels=TRUE)
MyDataGraph
## -- Subsetting Example
myCleanSubset <- SubsetCleaner(Example_data, fact="Plot", respo="Seed_removal_percent",
sub ="Season", warn=FALSE)
MySubsetGraph <- GraphCompare(myCleanSubset, groups=TRUE, clean_bg=TRUE, x_label="Plot",
y_label="Seed Removal Percent", bold_labels=TRUE,
vert_facet=TRUE)
MySubsetGraph
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.