Description Usage Arguments Value Author(s) See Also Examples
This function takes a list created by either SubsetCleaner or DataCleaner and conducts multiple t-test comparissons between the fact levels.
1 2 | Mult_T_Tests(data, groups = FALSE, paired = FALSE, test = "bonferroni",
alpha_value = 0.05, ...)
|
data |
Is a list output from either |
groups |
Either |
paired |
Is an aurgement passed to |
test |
Defaults to Bonferonni. Is passed to |
alpha_value |
Defaults to |
... |
Other arguments to be passed to |
Output_table |
consisting of a table with the comparison, p-values, adjusted p-values, and whether the adjusted p-value is less than or equal to the alpha value |
Summary_table |
a table with the |
Selina A. Ruzi
SubsetCleaner
DataCleaner
t.test
p.adjust
data.table
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 | ## -- find path
mypath <- system.file("extdata", "Example_data.csv", package="multipleComparisons")
## -- read in data
Example_data <- read.csv(mypath, header=TRUE)
names(Example_data)
## -- If do not want to further subset the data, do the following
myCleanData <- DataCleaner(Example_data, fact="Plot",
respo="Seed_removal_percent",
warn=FALSE)
## -- No Subsetting Example
myDataTests <- Mult_T_Tests(myCleanData, groups=FALSE)
## -- Subsetting Example
myCleanSubset <- SubsetCleaner(Example_data, fact="Plot", respo="Seed_removal_percent",
sub ="Season", warn=FALSE)
mySubsetTests <- Mult_T_Tests(myCleanSubset, groups=TRUE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.